<?php

namespace Agent;

require_once 'Lava.php';


class App extends \Lava\App {

	public	$setup, $settings,
		$cache,
		$api,
		$lang,  $lang_short,
		$dict,
		$currency;


	public function init () {

		$this->cache    = new Cache;

		$settings = $this->cache->store('settings');

		if   ($settings)
			foreach ($settings as $key => $val) {
				if (strpos($key, 'expire_') === 0)
					$this->cache->_expire(array(
						substr($key, 7) => $val
					));
			}
		else	$this->setup = TRUE;

		$langs    = $this->conf->langs();
		$short    = array();

		foreach (array_keys($langs) as $lang)
			$short[preg_replace('/-.+/', '', $lang)] = $lang;

		$accept   = array_merge(
			$this->args->get()->lang(),
			$this->cookie     ->lang(),
			$this->env        ->accept_language(),
			array_keys        ($langs)
		);

		foreach ($accept as $lang) {
			if (isset($langs[$lang])) {
				$this->lang = $lang;
				break;
			}
			if (isset($short[$lang])) {
				$this->lang = $short[$lang];
				break;
			}
		}
		list($this->lang_short) = explode('-', $this->lang);

		$this->currency = $this->lang_short == 'ru'	? 'RUR'
								: 'USD';
		$this->settings = new \Lava\Stash ($settings);

		$this->api      = new PlatiAPI (array(
			'guid_agent' => $this->settings->guid_agent,
			'lang'       => $this->lang,
			'currency'   => $this->currency,
		));

		$this->dict     = include "dict/$this->lang.php";
	}


	public function dict () {

		$args = func_get_args();
		if (! count($args)) return $this->dict;

		$data = (array)array_shift($args);

		foreach ($data as $key => &$val) {

			$index = count($args);
			$segs  = array_merge(
				$args, $key ? array($key, $val) : array($val)
			);

			while (count($segs)) {

				$word = strtolower(preg_replace(
					'/\s+/', '_', join('_', $segs)
				));

				if (isset($this->dict[$word])) {
					$val = $this->dict[$word];
					break;
				}

				array_splice($segs, $index ? --$index: 0, 1);
			}
		}

		if (count    ($data) == 1 && isset($data[0]))
			$data =       $data[0];
		if (is_string($data))
			$data = nl2br($data);

		return  $data;
	}

	public function cache ($name, $opts = NULL, $local = FALSE) {

		$id   = $this->api  -> serialize($name, $opts);
		$data = $this->cache->_get      ($name, $id);

		if (!  ($data || $local)) {
			$data = $this->api->$name($opts);
			$this->cache->_set($name, $id, $data);
		}
		return  $data;
	}

	public function store ($name, $data = NULL) {
		return isset($data)
			?        $this->cache->store($name, $data)
			: (array)$this->cache->store($name);
	}

	public function vars ($text, $data = NULL) {

		$data = (array)$data;

		$data['host']       = $this->host(TRUE);
		$data['url']        = $this->url ('');
		$data['uri']        = $this->uri ('');

		$data['lang']       = $this->lang;
		$data['lang_short'] = $this->lang_short;

		$data['year']       = date('Y');

		foreach ($data as $key => $val) {
			unset($data[$key]);
			if (! isset    ($val)) $val = '';
			if (  is_string($val) || is_numeric($val))
				$data["{{$key}}"]   = $val;
		}
		return str_replace(
			array_keys($data), array_values($data), $text
		);
	}

	public function metric_size  ($size) {
		return FS::size($size);
	}

	public function format_price ($price, $currency = NULL) {

		if   (is_null ($currency))
			$currency = $this->currency;

		if   (is_array($price)) {
			if   (isset     ($price[$currency]))
				$price = $price[$currency];
			else	return;
		}

		if   (preg_match('/\.\d{3,}/', $price))
			$price    = round($price, 2);

		if   ($currency == 'USD')
			return	  '$'
				. $price;
		else
			return	  $price
				. '&nbsp;'
				. $this->dict($currency, 'currency');
	}

	public function icon_src ($idd, $maxlength = NULL) {

		$src = sprintf(
			'%s://%s?idd=%s',
			$this->env ->is_https ? 'https' : 'http',
			$this->conf->icon_src,
			$idd
		);

		if ($maxlength) $src .= "&maxlength=${maxlength}";

		return $src;
	}

	public function embed_code (array $attr) {

		if (! isset($attr['id']))		return;

		$attr['src'] = $this->uri('embed', array('id' => $attr['id']));
		$attr['id']  = "wgt-$attr[id]";

		if (! isset($attr['frameborder']))
			$attr['frameborder']       =  0;
		if (! isset($attr['scrolling']))
			$attr['scrolling']         = 'no';
		if (! isset($attr['width']))
			$attr['width']             = '100%';
		if (! isset($attr['height']))
			$attr['height']            =  0;
		if (! isset($attr['allowtransparency']))
			$attr['allowtransparency'] = TRUE;

		foreach ($attr as $key => $val)
			$attr[$key] = sprintf('%s="%s"', $key, htmlspecialchars($val));

		return '<iframe ' . join(' ', $attr) . '></iframe>';
	}
}

class PlatiAPI {

	private	$guid_agent,

		$lang,
		$currency,

		$timeout = 10;

	static
	private	$api = array(

			'goods'        => array(
				'uri'    => 'xml/goods.asp',
				'depend' => array('lang', 'currency'),
			),
			'goods_info'   => array(
				'uri'    => 'xml/goods_info.asp',
				'depend' => array(),
			),
			'seller_goods' => array(
				'uri'    => 'xml/seller_goods.asp',
				'depend' => array('lang', 'currency'),
			),
			'search'       => array(
				'uri'    => 'api/search.ashx',
				'depend' => array(),
			),
		);


	public function __construct ($opts) {
		foreach ($opts as $key => $val)
			if (property_exists($this, $key)) $this->$key = $val;
	}


	public function url ($name, $args = NULL) {

		if (! isset(self::$api[$name])) return;

		$url = 'http://www.plati.com/'   . self::$api[$name]['uri'];
		if (is_array($args)) $url .= '?' . http_build_query($args);

		return  $url;
	}

	public function serialize ($name, $opts) {

		$data = array();

		if (isset(self::$api[$name]))
			foreach (self::$api[$name]['depend'] as $depend)
				$data[] = $this->$depend;

		if (is_array($opts)) ksort($opts);
		$data[] = serialize($opts);

		return hash('md5', join(':', $data));
	}


	public function check_guid () {
		$res  = $this->_xml('goods_info', array('id_goods' => 1));
		return $res && strpos($res->retdesc, 'guid_agent') === FALSE;
	}


	public function goods (array $opts) {

		if (! isset($opts['currency']))	$opts['currency'] = $this->currency;

		$res  = $this->_xml('goods', $opts);
		if (! $res || (string)$res->retval !== '0') return;

		$data = array();

		$data['count'] = (int)$res->cnt_goods;
		$data['pages'] = (int)$res->pages;
		$data['page']  = (int)$res->page;
		$data['rows']  =      array();

		if ($res->rows)
			foreach ($res->rows->row as $row) {

				$item = array(
					'name'          => (string)$row->name_goods,
					'price'         => (float) str_replace(',', '.', $row->price),
					'currency'      => (string)$row->currency,
					'id_seller'     => (int)   $row->id_seller,
					'name_seller'   => (string)$row->name_seller,
					'rating_seller' => (float) str_replace(',', '.', $row->rating),
				);

				foreach ((array)$row->statistics as $key => $val)
					$item['statistics'][$key] = (int)$val;
				// может быть меньше нуля
				if (    $item['statistics']['cnt_badresponses'] < 0)
					$item['statistics']['cnt_badresponses'] = 0;

				$data['rows'][(int)$row->id_goods] = $item;
			}

		return  $data;
	}

	public function seller_goods ($opts) {

		if (! isset($opts['currency']))	$opts['currency'] = $this->currency;

		$res  = $this->_xml('seller_goods', $opts);
		if (! $res || (string)$res->retval !== '0' || ! $res->rows) return;

		$data = array();

		$data['id_seller']   = (int)   $res->id_seller;
		$data['name_seller'] = (string)$res->name_seller;
		$data['page']        = (int)   $res->page;
		$data['order']       = (string)$res->page;

		// указано дважды
		foreach ($res->cnt_goods as $cnt)
			if ((int)$cnt) $data['count'] = (int)$cnt;
		foreach ($res->pages     as $cnt)
			if ((int)$cnt) $data['pages'] = (int)$cnt;

		foreach ($res->rows->row as $row) {

			$item = array(
				'name'              => (string)$row->name_goods,
				'price'             => str_replace(',', '.', $row->price),
				'currency'          => (string)$row->currency,
				'cnt_sell'          => (int)   $row->cnt_sell,
				'cnt_return'        => (int)   $row->cnt_return,
				'cnt_goodresponses' => (int)   $row->cnt_goodresponses,
				'cnt_badresponses'  => (int)   $row->cnt_badresponses,
			);

			// может быть меньше нуля
			if (    $item['cnt_badresponses'] < 0)
				$item['cnt_badresponses'] = 0;

			$data['rows'][(int)$row->id_goods] = $item;
		}

		return  $data;
	}

	public function search (array $opts) {

		if (! isset($opts['query']))	$opts['query']    = '';
		if (! isset($opts['pagenum']))	$opts['pagenum']  = 1;

		$opts['response'] = 'json';

		$data = @json_decode(
			@file_get_contents($this->url('search', $opts)), TRUE
		);
		if (! (isset($data['items']) && count($data['items']))) return;

		foreach ($data['items'] as &$item) {

			$item['name']        = array(
				'en' => $item['name_eng'], 
				'ru' => $item['name'],
			);
			$item['description'] = array(
				'en' => $item['description_eng'], 
				'ru' => $item['description'],
			);
			$item['price']       = array();

			foreach ($item as $key => $val)
				if (preg_match('/^price_(\w+)/', $key, $match)) {
					$item['price'][strtoupper($match[1])] = $val;
					unset($item[$key]);
				}

			// может быть меньше нуля
			if (    $item['count_negativeresponses'] < 0)
				$item['count_negativeresponses'] = 0;

			unset($item['name_eng']);
			unset($item['name_translit']);
			unset($item['description_eng']);
			unset($item['url']);
			unset($item['image']);
		}

		return  $data;
	}


	private function _xml ($name, $content, $rm_declaration = FALSE) {

		$data = @file_get_contents(
			$this->url($name),
			FALSE,
			stream_context_create(array(
				'http' => array(
					'method'  => 'POST',
					'header'  => 'Content-Type: application/x-www-form-urlencoded' . PHP_EOL,
					'content' => $this->_request($content),
					'timeout' => $this->timeout,
				)
			))
		);

		if ($rm_declaration)
			$data = preg_replace('/^<\?xml\s+.*?\?>/i', '', $data);

		return @simplexml_load_string($data);
	}

	private function _request (array $opts) {

		$opts['guid_agent'] = $this->guid_agent;
		$opts['lang']       = $this->lang;

		$request = array();

		foreach ($opts as $k => $v)
			$request[] = sprintf(
				'<%s>%s</%s>',
				$k, htmlspecialchars($v), $k
			);

		return	  '<digiseller.request>'
			. join('', $request)
			. '</digiseller.request>';
	}
}

class Cache {

	static
	private $data   = array(),
		$expire = array();


	public function __call ($key, $args) {
		$id =  array_shift($args);
		return count      ($args)
			? self::_set($key, $id, array_shift($args))
			: self::_get($key, $id);
	}


	static
	public function _expire () {

		$expire = &self::$expire;

		if (func_num_args()) {
			$args = func_get_arg(0);
			foreach ($args as $key  => $val)
				$expire  [$key] =  $val;
		}

		return  $expire;
	}

	static
	public function _get ($key, $id = 0) {

		$data = &self::$data;
		$file =  self::_path($key, $id);

		if (file_exists($file)) {

			$age = (time() - filemtime($file)) / 60;

			if   (	   isset(self::$expire[$key])
				&&       self::$expire[$key] < $age
			)
			{
				unlink (      $file);
				unset  ($data[$file]);
			}
			else {
				if (! isset($data[$file]))
					$data[$file] = require $file;
				return  $data[$file];
			}
		}
	}

	static
	public function _set ($key, $id, $dump) {

		$expire = self::$expire;
		$file   = self::_path ($key, $id);

		if     (      isset($dump)
			&& (! isset($expire[$key]) || $expire[$key])
		)
		{
			$fh = fopen($file, 'w')
			or die("Can't open file: ${file}");

			flock ($fh, LOCK_EX)
			or die("Failed to lock the file: ${file}");

			fwrite($fh, sprintf(
				'<?php return %s; ?>',
				var_export($dump, TRUE)
			))
			or die("Can't write to the file: ${file}");

			flock ($fh, LOCK_UN)
			or die("Failed to unlock the file: ${file}");

			fclose($fh)
			or die("Can't close file: ${file}");

			self::$data[$file] = $dump;

			return TRUE;
		}
		elseif (file_exists($file)) {
			unlink($file);
			return TRUE;
		}
	}

	static
	public function _path () {

		$file = join('.', func_get_args());

		return $file	? "cache/${file}.php"
				: 'cache';
	}

	static
	public function _clear ($all = FALSE) {

		$path   = self::_path();
		$expire = self::_expire();

		if ($dh = opendir($path)) {

			while ($file  = readdir($dh)) {

				$key  = substr($file, 0, strpos($file, '.'));
				if (! isset($expire[$key])) continue;

				$full = "${path}/${file}";
				$age  = (time() - filemtime($full)) / 60;

				if ($all || $age >= $expire[$key])
					unlink($full);
			}

			closedir($dh);
		}
	}
}

class FS {

	static
	private $metric = array(
		'', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y',
	);

	static
	public function size ($size) {

		foreach (array_keys(self::$metric) as $exp)
			if ($size < pow(1024, $exp + 1)) break;

		return sprintf(
			'%.' . ($exp ? 2 : 0) . 'f %sB',
			$size / pow(1024, $exp),
			self::$metric    [$exp]
		);
	}
}

?>
