<?php
	if (! defined('HAS_APP')) exit;

	$is_demo  = $app->conf->is_demo;

	$settings = $app->settings;

	if ($is_demo)
		foreach (array('id_agent', 'guid_agent') as $key)
			$settings->$key = str_pad(NULL, strlen($settings->$key), '*');

	$is_post  = $app->env->is_post;
	$args     = $app->args;

	$error    = $app->stash->error();

	$app->stash->title = $app->dict('Settings');

	include 'templates/_header.php';
?>
<div id="settings" class="container">
	<?php if ($is_demo): ?>
		<div class="alert alert-info text-center" role="alert"><?php echo $app->dict('Demo mode') ?></div>
	<?php endif; ?>
	<form method="POST" role="form">
		<fieldset<?php if ($is_demo) echo ' disabled' ?>>
			<div class="page-header">
				<h3><?php echo $app->dict('Dashboard') ?></h3>
			</div>
			<?php if ($app->setup && isset($app->dict['helper_settings_dashboard'])): ?>
				<div class="alert alert-info" role="alert">
					<?php echo $app->vars($app->dict('helper_settings_dashboard')) ?>
				</div>
			<?php endif; ?>
			<div class="form-group<?php if (isset($error['auth'])) echo ' has-error' ?>">
				<label for="auth" class="control-label"><?php echo $app->dict('Auth page') ?>*</label>
				<?php if (isset($app->dict['helper_settings_auth'])): ?>
					<button type="button" class="btn btn-xs btn-link" tabindex="-1" data-toggle="tooltip" data-placement="right" title="<?php echo htmlspecialchars($app->dict['helper_settings_auth']) ?>">
						<span class="glyphicon glyphicon-info-sign" aria-hidden="true"></span>
					</button>
				<?php endif; ?>
				<input type="text" id="auth" name="auth" value="<?php echo htmlspecialchars($is_post ? $args->auth : $settings->auth) ?>" class="form-control">
				<?php if (isset($error['auth'])): ?>
					<div class="help-block small"><?php echo $error['auth'] ?></div>
				<?php endif; ?>
			</div>
			<div class="form-group<?php if (isset($error['password'])) echo ' has-error' ?>">
				<label for="password" class="control-label"><?php echo $app->dict('Password') ?>*</label>
				<?php if (isset($app->dict['helper_settings_password'])): ?>
					<button type="button" class="btn btn-xs btn-link" tabindex="-1" data-toggle="tooltip" data-placement="right" title="<?php echo htmlspecialchars($app->dict['helper_settings_password']) ?>">
						<span class="glyphicon glyphicon-info-sign" aria-hidden="true"></span>
					</button>
				<?php endif; ?>
				<input type="password" id="password" name="password" value="<?php echo htmlspecialchars($is_post ? $args->password : $settings->password) ?>" class="form-control">
				<?php if (isset($error['password'])): ?>
					<div class="help-block small"><?php echo $error['password'] ?></div>
				<?php endif; ?>
			</div>
			<div class="page-header">
				<h3><?php echo $app->dict('Plati.ru') ?></h3>
			</div>
			<?php if ($app->setup && isset($app->dict['helper_settings_plati'])): ?>
				<div class="alert alert-info" role="alert">
					<?php echo $app->dict('helper_settings_plati') ?>
				</div>
			<?php endif; ?>
			<div class="form-group<?php if (isset($error['id_agent'])) echo ' has-error' ?>">
				<label for="id_agent" class="control-label"><?php echo $app->dict('ID agent') ?>*</label>
				<?php if (isset($app->dict['helper_settings_id_agent'])): ?>
					<button type="button" class="btn btn-xs btn-link" tabindex="-1" data-toggle="tooltip" data-placement="right" title="<?php echo htmlspecialchars($app->dict['helper_settings_id_agent']) ?>">
						<span class="glyphicon glyphicon-info-sign" aria-hidden="true"></span>
					</button>
				<?php endif; ?>
				<input type="text" id="id_agent" name="id_agent" value="<?php echo htmlspecialchars($is_post ? $args->id_agent : $settings->id_agent) ?>" class="form-control auto" placeholder="123456">
				<?php if (isset($error['id_agent'])): ?>
					<div class="help-block small"><?php echo $error['id_agent'] ?></div>
				<?php endif; ?>
			</div>
			<div class="form-group<?php if (isset($error['guid_agent'])) echo ' has-error' ?>">
				<label for="guid_agent" class="control-label"><?php echo $app->dict('GUID agent') ?>*</label>
				<?php if (isset($app->dict['helper_settings_guid_agent'])): ?>
					<button type="button" class="btn btn-xs btn-link" tabindex="-1" data-toggle="tooltip" data-placement="right" title="<?php echo htmlspecialchars($app->dict['helper_settings_guid_agent']) ?>">
						<span class="glyphicon glyphicon-info-sign" aria-hidden="true"></span>
					</button>
				<?php endif; ?>
				<input type="text" id="guid_agent" name="guid_agent" value="<?php echo htmlspecialchars($is_post ? $args->guid_agent : $settings->guid_agent) ?>" class="form-control" placeholder="0123456789ABCDEF0123456789ABCDEF">
				<?php if (isset($error['guid_agent'])): ?>
					<div class="help-block small"><?php echo $error['guid_agent'] ?></div>
				<?php endif; ?>
			</div>
			<div class="page-header">
				<h3><?php echo $app->dict('Cache') ?></h3>
			</div>
			<?php if ($app->setup && isset($app->dict['helper_settings_cache'])): ?>
				<div class="alert alert-info" role="alert">
					<?php echo $app->dict('helper_settings_cache') ?>
				</div>
			<?php endif; ?>
			<?php foreach (array('goods', 'seller_goods', 'search') as $name): ?>
				<div class="form-group<?php if (isset($error["expire_${name}"])) echo ' has-error' ?>">
					<label for="<?php echo "expire_${name}" ?>" class="control-label"><?php echo $app->dict($name, 'cache') ?>*</label>
					<?php if (isset($app->dict['helper_settings_expire'])): ?>
						<button type="button" class="btn btn-xs btn-link" tabindex="-1" data-toggle="tooltip" data-placement="right" title="<?php echo htmlspecialchars($app->dict['helper_settings_expire']) ?>">
							<span class="glyphicon glyphicon-info-sign" aria-hidden="true"></span>
						</button>
					<?php endif; ?>
					<input type="text" id="<?php echo "expire_${name}" ?>" name="<?php echo "expire_${name}" ?>" value="<?php echo htmlspecialchars($is_post ? $args->{"expire_${name}"} : ($app->setup ? 60 : $settings->{"expire_${name}"})) ?>" class="form-control auto">
					<?php if (isset($error["expire_${name}"])): ?>
						<div class="help-block small"><?php echo $error["expire_${name}"] ?></div>
					<?php endif; ?>
				</div>
			<?php endforeach; ?>
			<button type="submit" class="btn btn-sm btn-primary">
				<span class="glyphicon glyphicon-save"></span>
				<?php echo $app->dict('Save') ?>
			</button>
		</fieldset>
	</form>
</div>
<?php
	include 'templates/_footer.php';
?>
